<?php
namespace FiloBlu\Rma\Model;

use FiloBlu\Rma\Api\RmaManagementInterface;
use FiloBlu\Rma\Handlers\CanCreateRmaHandler;
use Magento\Framework\DataObject;
use Magento\Rma\Model\ResourceModel\Item;
use Magento\Sales\Api\OrderRepositoryInterface;

class RmaManagement implements RmaManagementInterface
{
    /**
     * @var Item
     */
    private $item;

    /**
     * @var DataObject
     */
    private $dataObject;
    /**
     * @var CanCreateRmaHandler
     */
    private $canCreateRmaHandler;
    /**
     * @var OrderRepositoryInterface
     */
    private $orderRepository;

    /**
     * RmaManagement constructor.
     * @param Item $item
     * @param DataObject $dataObject
     * @param CanCreateRmaHandler $canCreateRmaHandler
     * @param OrderRepositoryInterface $orderRepository
     */
    public function __construct(Item $item, DataObject $dataObject,
    CanCreateRmaHandler $canCreateRmaHandler,
    OrderRepositoryInterface $orderRepository)
    {
        $this->item = $item;
        $this->dataObject = $dataObject;
        $this->canCreateRmaHandler = $canCreateRmaHandler;
        $this->orderRepository = $orderRepository;
    }

    /**
     * @param int $orderId
     * @return DataObject
     */
    public function getReturnableItems(int $orderId)
    {

       $items = $this->item->getReturnableItems($orderId) ?? [];
       $isReturnable = $this->isReturnable($orderId);
       foreach ($items as $k=>$v){
           if($isReturnable){
               if($v>0){
                   $this->dataObject->setData($k,["item_id"=>$k,"returnable_qty"=>$v]);
               }
           }else{
               $this->dataObject->setData($k,["item_id"=>$k,"returnable_qty"=>0]);
           }

       }

       return  $this->dataObject->getData();

    }

    /**
     * @param int $orderId
     * @return bool
     */
    protected function isReturnable(int $orderId){
        try {
            $order = $this->orderRepository->get($orderId);
            return $this->canCreateRmaHandler->getCanOrderCreateRma($order);
        }catch (\Exception $e){

        }catch (\Throwable $t){

        }
        return false;
    }

}
